| Safe Haskell | Trustworthy |
|---|
Language.Nomyx
Description
This module re-exports the elements necessary to compose a Nomyx rule.
Nomyx-Language-0.5.0: Language to express rules for Nomic
| Safe Haskell | Trustworthy |
|---|
Language.Nomyx
Description
This module re-exports the elements necessary to compose a Nomyx rule.